.. pynoc documentation master file, created by
   sphinx-quickstart on Fri Feb 26 16:44:45 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pynoc's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   pynoc

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

